#!/bin/sh

# NAME:
#	dynsoa.sh - create an SOA file for a dynamic zone
#
# SYNOPSIS:
#	dynsoa.sh -M "mail" -n "ns" -o "file" "domain"
#
# DESCRIPTION:
#	Similar to updsoa but output to "file" (stdout).
#	
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: dynsoa.sh,v 1.3 2023/06/11 05:48:11 sjg Exp $
#
#	@(#) Copyright (c) 2022 Simon J. Gerraty.
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Myname=dynsoa
Mydir=`dirname $0`
rc=.${Myname}rc

opt_str=e:f:I:M:m:N:n:o:r:T:u
opt_M=hostmaster.crufty.net
opt_n=ns.crufty.net
opt_f=14400			# reFresh 4 hours
opt_r=1800			# Retry 1/2 hour
opt_e=3600000			# Expire 1000 hours
opt_m=14400			# Minimum ttl

source() {
	f=$1; shift
	ds="${*:-. $Mydir /etc}"

	for d in $ds
	do
		test -s $d/$f && { . $d/$f; break; }
	done
}

source dns.rc
source .dnsrc
source updsoa.rc
source .updsoarc
source $rc

today=`date "+%Y%m%d"`

. setopts.sh

case "$opt_M" in
*@*)	# some people never read the manual
        opt_M=`echo $opt_M | tr '@' '.'`
        ;;
esac
opt_N=${opt_N:-$opt_n}
if [ -s $opt_N ]; then
    NSLIST="\$INCLUDE $opt_N"
else
    NSLIST="	IN	NS	$opt_N."
fi
if [ -n "$opt_T" ]; then
    TTL="\$TTL $opt_T"
fi
case "$opt_u" in
1|-u)	serial=`secs`;;
esac
serial=${serial:-${today}00}

test -z "$opt_o" || exec > $opt_o
cat <<! | sed 's/\.\./\./g'
;; DO NOT EDIT THIS FILE it is maintained by magic
;; see sjg for questions...
;;
$TTL   
@       IN      SOA     $opt_n. $opt_M.  (
                                $serial	; Last changed by - $USER
                                $opt_f		; Refresh
                                $opt_r		; Retry
                                $opt_e		; Expire 
                                $opt_m )	; Minimum TTL
$NSLIST

!

if [ -s ${opt_I:-/dev/null} ]; then
    echo "\$INCLUDE $opt_I"
fi
case "${1:-$opt_o}" in
*.[1-9]*) ;;
*) cat <<EOF    
localhost	IN	A	127.0.0.1
		IN	AAAA	::1

EOF
   ;;
esac
echo ";;"

