:
# NAME:
#	spacefor.sh - check for available space
#
# DESCRIPTION:
#	We use spacefor(1) if it exists, otherwise we use df(1) and
#	friends. 
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#

# RCSid:
#	$Id: spacefor.sh,v 1.7 2001/12/11 08:08:49 sjg Exp $
#
#	@(#) Copyright (c) 1995 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

[ "$LOCAL_FS" ] || . ${RC_D:-/etc/rc_d}/os.sh
DU=${DU:-"du $K"}
DF=${DF:-"df $K"}


file_size() {
	set -- `$DU -s $1`
	echo $1
}

if [ -x /usr/local/bin/spacefor ]; then
        SPACEFOR=/usr/local/bin/spacefor

space_for() { $SPACEFOR $*; }
        
space_on() { $SPACEFOR $*; }
        
else

space_on() {
	dir=$1
	avail=0

	if [ -d $dir ]; then
		avail=`$DF $dir | awk '/%.*\// { F=NF - 2; print $F }'`
	else
		echo "$dir: does not exist" >&2
	fi
	echo $avail
}

space_for() {
	dir=$1
	want=$2			# kbytes or filename
	[ -f $want ] && want=`file_size $2`
	avail=`space_on $dir`
	[ ${avail:-0} -ge $want ]
}

fi

space_all() {
	$DF | awk '/%.*\// { F=NF - 2; print $NF "=" $F }' |
		sed -e 's,/,_,g' -e 's,^_=,_root=,' -e "s,^,${1:-df},"
}

case $0 in
*spacefor*) space_for $*;;
*spaceall*) space_all $*;;
*spaceon*) space_on $*;;
esac
