:
# NAME:
#	mktemp.sh - portable mktemp
#
# SYNOPSIS:
#	Mktemp [-d] [-q] [-u] [-t "prefix"] ["template" ...]
#	
# DESCRIPTION:
#	Mktemp implements mktemp(1) as found in recent BSD's.
#	If mktemp(1) exists MKTEMP is set to its path, otherwise it is
#	set to Mktemp.
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>

# RCSid:
#	$Id: mktemp.sh,v 1.2 2002/12/31 01:44:35 sjg Exp $
#
#	@(#) Copyright (c) 1994 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

_MKTEMP_SH=:

_Mktemp1() {
    t=$1
    template=`echo $2 | sed 's,XX*,$XX,'`
    err=${3:-echo}
    base=`dirname $template`
    x=1

    [ -d $base ] || mkdir -p $base 2>/dev/null
    [ -d $base ] || { $err mktemp: cannot create $base >&2; return; }
    case "$t" in
    -f) tf=$base/,t$$,${RANDOM:-$$}
        rm -f $tf
        > $tf
        ;;
    esac

    while :
    do
        XX=$$.$x
	eval target=$template
        [ -h $target ] && continue # someone playing tricks!
	case "$t" in
    	-f) ln $tf $target 2> /dev/null && { rm -f $tf; echo $target; return; };;
        *) mkdir $target && { echo $target; return; };;
	esac
        x=`expr $x + 1`
        [ $x = 2000 ] && break
    done
    case "$t" in
    -f) rm -f $tf;;
    esac
    $err mktemp: cannot create $template
}

Mktemp() {
    (
    err=echo
    prefix=""
    t=-f
    
    while :
    do
        case "$1" in
	-u) shift;;
	-t) prefix=${TMPDIR:-/tmp}/$2.XXXXX; shift 2;;
	-q) err=:; shift;;
	-d) t=-d; shift;;
	--) shift; break;;
	*) break;;
	esac
    done

    for prefix in $prefix $*
    do
        (umask 077; _Mktemp1 $t $prefix $err )
    done
    )    
}

[ -x /usr/bin/mktemp ] && MKTEMP=/usr/bin/mktemp || MKTEMP=Mktemp

case ./$0 in
*/mktemp.sh)
    Mktemp "$@"
    ;;
esac

